# pds.api-client
Registry API enabling advanced search on PDS data and metadata. The API provides end-points to search for bundles, collections and any PDS products with advanced search queries. It also enables to browse the archive hierarchically downward (e.g. collection/s products) or upward (e.g. bundles containing a product).


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.5.0
- Package version: 1.6.1
- Generator version: 7.4.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pds.api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pds.api_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import pds.api_client
from pds.api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://pds.nasa.gov/api/registry/1
# See configuration.py for a list of all supported configuration parameters.
configuration = pds.api_client.Configuration(
    host = "https://pds.nasa.gov/api/registry/1"
)



# Enter a context with an instance of the API client
with pds.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pds.api_client.AllDocsApi(api_client)
    indices = ['indices_example'] # List[str] | syntax: indices=index1,index2... notes: OpenSearch indices 
    body = 'body_example' # str | OpenSearch DSL query

    try:
        # WORK IN PROGRESS: search on all registry documents by posting an OpenSearch DSL query 
        api_response = api_instance.docs(indices, body)
        print("The response of AllDocsApi->docs:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AllDocsApi->docs: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://pds.nasa.gov/api/registry/1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AllDocsApi* | [**docs**](docs/AllDocsApi.md#docs) | **POST** /docs | WORK IN PROGRESS: search on all registry documents by posting an OpenSearch DSL query 
*AllProductsApi* | [**product_list**](docs/AllProductsApi.md#product_list) | **GET** /products | search the latest-versioned instances of all PDS data products, including bundles, collections, documentation, context and observational products. 
*AllProductsApi* | [**product_properties_list**](docs/AllProductsApi.md#product_properties_list) | **GET** /properties | return a list of all possible searchable metadata fields for products published in the registry 
*AllProductsApi* | [**select_by_lidvid**](docs/AllProductsApi.md#select_by_lidvid) | **GET** /products/{identifier} | returns one PDS Product with the identifier selected from all PDS Products, including bundles, collections, data, documentation, context and observational products. See identifier for details on how it determines what is returned. 
*AllProductsApi* | [**select_by_lidvid_all**](docs/AllProductsApi.md#select_by_lidvid_all) | **GET** /products/{identifier}/all | returns all product versions with the identifier (lid) selected from all PDS Products. See identifier for details on how it determines what is returned.  note: if given a lidvid, it will be translated to a lid 
*AllProductsApi* | [**select_by_lidvid_latest**](docs/AllProductsApi.md#select_by_lidvid_latest) | **GET** /products/{identifier}/latest | returns one PDS Product with the identifier selected from all PDS Products. See identifier for details on how it determines what is returned. 
*ByProductClassesApi* | [**class_list**](docs/ByProductClassesApi.md#class_list) | **GET** /classes/{class} | returns all PDS products of the given PDS product class that meet all given constraints. 
*ByProductClassesApi* | [**classes**](docs/ByProductClassesApi.md#classes) | **GET** /classes | returns a list of the available PDS product class at this API. This is not all of the PDS product class available in the database, but simply the names that can be used in the /classes/{class} endpoints. 
*HealthcheckApi* | [**healthcheck**](docs/HealthcheckApi.md#healthcheck) | **GET** /healthcheck | returns payload of system health information. Detection of any fatal issues results in a non-200 response. The primary intention of this endpoint is to provide an accurate assessment of the service to determine if ECS/Fargate should instantiate a new instance of the task. 
*ProductReferencesApi* | [**product_member_of**](docs/ProductReferencesApi.md#product_member_of) | **GET** /products/{identifier}/member-of | returns one or more PDS Products that have the given PDS lid/lidvid as a member. 
*ProductReferencesApi* | [**product_member_of_of**](docs/ProductReferencesApi.md#product_member_of_of) | **GET** /products/{identifier}/member-of/member-of | returns one or more PDS Products that have the given PDS lid/lidvid as a member of its members. 
*ProductReferencesApi* | [**product_member_of_of_vers**](docs/ProductReferencesApi.md#product_member_of_of_vers) | **GET** /products/{identifier}/member-of/member-of/{versions} | returns one or more PDS Products that have the given PDS lid/lidvid as a member of its members. 
*ProductReferencesApi* | [**product_member_of_vers**](docs/ProductReferencesApi.md#product_member_of_vers) | **GET** /products/{identifier}/member-of/{versions} | returns one or more PDS Products that have the given PDS lid/lidvid as a member. 
*ProductReferencesApi* | [**product_members**](docs/ProductReferencesApi.md#product_members) | **GET** /products/{identifier}/members | returns all of the members of the given lid/lidvid 
*ProductReferencesApi* | [**product_members_members**](docs/ProductReferencesApi.md#product_members_members) | **GET** /products/{identifier}/members/members | returns all of the members of the members of the given lid/lidvid 
*ProductReferencesApi* | [**product_members_members_vers**](docs/ProductReferencesApi.md#product_members_members_vers) | **GET** /products/{identifier}/members/members/{versions} | returns all of the members of the members of the given lid/lidvid 
*ProductReferencesApi* | [**product_members_vers**](docs/ProductReferencesApi.md#product_members_vers) | **GET** /products/{identifier}/members/{versions} | returns all of the members of the given lid/lidvid 


## Documentation For Models

 - [ErrorMessage](docs/ErrorMessage.md)
 - [Metadata](docs/Metadata.md)
 - [Pds4Metadata](docs/Pds4Metadata.md)
 - [Pds4MetadataOpsDataFile](docs/Pds4MetadataOpsDataFile.md)
 - [Pds4MetadataOpsLabelFileInfo](docs/Pds4MetadataOpsLabelFileInfo.md)
 - [Pds4MetadataOpsTrackingMeta](docs/Pds4MetadataOpsTrackingMeta.md)
 - [Pds4Product](docs/Pds4Product.md)
 - [Pds4Products](docs/Pds4Products.md)
 - [PdsProduct](docs/PdsProduct.md)
 - [PdsProducts](docs/PdsProducts.md)
 - [PropertiesListInner](docs/PropertiesListInner.md)
 - [Reference](docs/Reference.md)
 - [Summary](docs/Summary.md)
 - [WyriwygProduct](docs/WyriwygProduct.md)
 - [WyriwygProductKeyValuePair](docs/WyriwygProductKeyValuePair.md)
 - [WyriwygProducts](docs/WyriwygProducts.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author

pds-operator@jpl.nasa.gov


